@@ -119,6 +119,7 @@ private Q_SLOTS:
         QCOMPARE(fromKPluginLoader, fromRawData);
         QCOMPARE(fromFullPath, fromKPluginLoader);
         QCOMPARE(fromRawData, fromKPluginLoader);
+        QVERIFY(!KPluginMetaData(KPluginLoader(QStringLiteral("doesnotexist"))).isValid());
 #endif
 
         QVERIFY(fromQPluginLoader.isValid());
@@ -138,12 +139,14 @@ private Q_SLOTS:
         QCOMPARE(fromQPluginLoader, fromFullPath);
         QCOMPARE(fromQPluginLoader, fromRawData);
 
-
         QCOMPARE(fromFullPath, fromQPluginLoader);
         QCOMPARE(fromFullPath, fromRawData);
 
         QCOMPARE(fromRawData, fromQPluginLoader);
         QCOMPARE(fromRawData, fromFullPath);
+
+        QVERIFY(!KPluginMetaData(QPluginLoader(QStringLiteral("doesnotexist"))).isValid());
+        QVERIFY(!KPluginMetaData(QJsonObject(), QString()).isValid());
     }
 
     void testAllKeys()
